# Change History

## 2021.10.24

* Changed the commandline API now using commands
* Commandline API now based on [Typer](https://pypi.org/project/typer/)
* Changed development tools
* For now no updates to the docker image ...
* Added a wheel to the package

## 0.0.6 (2021-04-29)

* Removed duplicates from arguments
* Backported to Python 3.7 and optimizing log payloads
* Sixth release on PyPI

## 0.0.5 (2021-04-28)

* Hot fix for optimized empty csv and xml file handling
* Fifth release on PyPI

## 0.0.4 (2021-04-28)

* Fixed gelee app (console script)
* Fixed single file path use case
* Enhanced detection of and report on empty CSV as well as XML files (invalid use cases)
* Enhanced report on non-existing paths
* Added more tests to detect regressions
* Fixed summary singular / plural for total paths
* Fourth release on PyPI

## 0.0.3 (2021-04-27)

* Added YAML well-formed lint
* Hardened processing of files without extension
* Added documentation
* Third release on PyPI

## 0.0.2 (2021-04-26)

* Added CSV well-formed lint
* Added INI well-formed lint
* Added JSON/GeoJSON well-formed lint
* Added TOML well-formed lint
* Added XML well-formed lint
* Fixed debug logic
* Second release on PyPI

## 0.0.1 (2021-04-25)

* Initial release on PyPI

